﻿using database;

namespace Forms
{
    public partial class FormBranch : Form
    {
        private Abstractions bd;
        public FormBranch(Abstractions _bd)
        {
            InitializeComponent();
            bd = _bd;
        }
        private void loadData()
        {
            // Получаем список филиалов
            List<Branch> branches = bd.GetBranches();

            // Очищаем dataGridView перед заполнением новыми данными
            dataGridView.Rows.Clear();

            // Предварительно определяем столбцы, если это не было сделано ранее
            if (dataGridView.ColumnCount == 0)
            {
                dataGridView.Columns.Add("Id", "ID");
                dataGridView.Columns.Add("Name", "Name");
                dataGridView.Columns.Add("Address", "Address");
                dataGridView.Columns.Add("Phone", "Phone");
                dataGridView.Columns.Add("WorkingHours", "Working Hours");
            }

            // Заполняем dataGridView данными из списка филиалов
            foreach (Branch branch in branches)
            {
                dataGridView.Rows.Add(branch.Id, branch.Name, branch.Address, branch.Phone, branch.WorkingHours);
            }

        }

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // Создаем новый объект Branch и заполняем его данными из текстовых полей
            Branch newBranch = new Branch
            {
                Name = textBoxName.Text,
                Address = textBoxAddress.Text,
                Phone = textBoxPhone.Text,
                WorkingHours = textBoxWorkingHours.Text
            };

            // Вызываем метод добавления нового филиала в базу данных
            bd.AddBranch(newBranch);

            // Перезагружаем данные в dataGridView
            loadData();
        }

        private void buttonUpdate_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем выбранный филиал из dataGridView
                DataGridViewRow selectedRow = dataGridView.SelectedRows[0];
                int branchId = Convert.ToInt32(selectedRow.Cells["Id"].Value);

                // Создаем объект Branch с обновленными данными из текстовых полей
                Branch updatedBranch = new Branch
                {
                    Id = branchId,
                    Name = textBoxName.Text,
                    Address = textBoxAddress.Text,
                    Phone = textBoxPhone.Text,
                    WorkingHours = textBoxWorkingHours.Text
                };

                // Вызываем метод обновления филиала в базе данных
                bd.UpdateBranch(updatedBranch);

                // Перезагружаем данные в dataGridView
                loadData();
            }
            else
            {
                MessageBox.Show("Please select a branch to update.");
            }
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем выбранный филиал из dataGridView
                DataGridViewRow selectedRow = dataGridView.SelectedRows[0];
                int branchId = Convert.ToInt32(selectedRow.Cells["Id"].Value);

                // Вызываем метод удаления филиала из базы данных
                bd.DeleteBranch(branchId);

                // Перезагружаем данные в dataGridView
                loadData();
            }
            else
            {
                MessageBox.Show("Please select a branch to delete.");
            }
        }

        private void dataGridView_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex >= 0)
            {
                DataGridViewRow row = dataGridView.Rows[e.RowIndex];

                textBoxName.Text = row.Cells["Name"].Value.ToString();
                textBoxAddress.Text = row.Cells["Address"].Value.ToString();
                textBoxPhone.Text = row.Cells["Phone"].Value.ToString();
                textBoxWorkingHours.Text = row.Cells["WorkingHours"].Value.ToString();
            }
        }

        private void FormBranch_Load(object sender, EventArgs e)
        {
            loadData();
        }
    }
}
