﻿using database;
using System.Data;

namespace Forms
{
    public partial class FormCar : Form
    {
        private Abstractions bd;
        public FormCar(Abstractions _bd)
        {
            InitializeComponent();
            bd = _bd;
        }
        private void loadData()
        {
            // Получаем список автомобилей
            List<Car> cars = bd.GetCars();

            // Очищаем dataGridView перед заполнением новыми данными
            dataGridView.Rows.Clear();

            // Предварительно определяем столбцы, если это не было сделано ранее
            if (dataGridView.ColumnCount == 0)
            {
                dataGridView.Columns.Add("Id", "ID");
                dataGridView.Columns.Add("ModelId", "ModelId");
                dataGridView.Columns["ModelId"].Visible = false;
                dataGridView.Columns.Add("Model", "Model");
                dataGridView.Columns.Add("BranchId", "BranchId");
                dataGridView.Columns["BranchId"].Visible = false;
                dataGridView.Columns.Add("Branch", "Branch");
                dataGridView.Columns.Add("Year", "Year");
                dataGridView.Columns.Add("Mileage", "Mileage");
                dataGridView.Columns.Add("StatusId", "StatusId");
                dataGridView.Columns["StatusId"].Visible = false;
                dataGridView.Columns.Add("Status", "Status");
            }

            // Заполняем комбо-боксы данными из БД
            comboBoxBranch.DataSource = bd.GetBranches();
            comboBoxBranch.DisplayMember = "Name";
            comboBoxBranch.ValueMember = "Id";

            comboBoxModel.DataSource = bd.GetCarModels()
                .Select(x => new helpCombobox()
                {
                    Text = x.Brand + " " + x.Model,
                    Id = x.Id
                }).ToList();
            comboBoxModel.DisplayMember = "Text";
            comboBoxModel.ValueMember = "Id";

            comboBoxStatus.DataSource = bd.GetStatuses();
            comboBoxStatus.DisplayMember = "Title";
            comboBoxStatus.ValueMember = "Id";

            // Заполняем dataGridView данными из списка автомобилей
            foreach (Car car in cars)
            {
                dataGridView.Rows.Add(car.Id,
                    car.ModelId,
                    bd.GetCarModelById(car.ModelId).Brand + " " + bd.GetCarModelById(car.ModelId).Model,
                    car.BranchId,
                    bd.GetBranchById(car.BranchId).Name,
                    car.Year, car.Mileage,
                    car.StatusId,
                    bd.GetStatusById(car.StatusId).Title);
            }

        }
        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // Создаем новый объект Car и заполняем его данными из текстовых полей и комбо-боксов
            Car newCar = new Car
            {
                Mileage = int.Parse(textBoxMileage.Text),
                Year = int.Parse(textBoxYear.Text),
                BranchId = ((Branch)comboBoxBranch.SelectedItem).Id,
                ModelId = ((helpCombobox)comboBoxModel.SelectedItem).Id,
                StatusId = ((Status)comboBoxStatus.SelectedItem).Id
            };

            // Вызываем метод добавления нового автомобиля в базу данных
            bd.AddCar(newCar);

            // Обновляем dataGridView
            loadData();
        }

        private void buttonUpdate_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем индекс выбранной строки
                int rowIndex = dataGridView.CurrentCell.RowIndex;

                // Получаем ID редактируемого автомобиля из выбранной строки dataGridView
                int carId = (int)dataGridView.Rows[rowIndex].Cells["Id"].Value;

                // Создаем объект Car и заполняем его данными из текстовых полей и комбо-боксов
                Car updatedCar = new Car
                {
                    Id = carId,
                    Mileage = int.Parse(textBoxMileage.Text),
                    Year = int.Parse(textBoxYear.Text),
                    BranchId = ((Branch)comboBoxBranch.SelectedItem).Id,
                    ModelId = ((helpCombobox)comboBoxModel.SelectedItem).Id,
                    StatusId = ((Status)comboBoxStatus.SelectedItem).Id
                };

                // Вызываем метод обновления автомобиля в базе данных
                bd.UpdateCar(updatedCar);

                // Обновляем dataGridView
                loadData();
            }
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем индекс выбранной строки
                int rowIndex = dataGridView.CurrentCell.RowIndex;

                // Получаем ID удаляемого автомобиля из выбранной строки dataGridView
                int carId = (int)dataGridView.Rows[rowIndex].Cells["Id"].Value;

                // Вызываем метод удаления автомобиля из базы данных
                bd.DeleteCar(carId);

                // Обновляем dataGridView
                loadData();
            }
        }

        private void dataGridView_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex >= 0)
            {
                DataGridViewRow row = dataGridView.Rows[e.RowIndex];

                // Заполняем текстовые поля данными из выбранной строки
                textBoxMileage.Text = row.Cells["Mileage"].Value.ToString();
                textBoxYear.Text = row.Cells["Year"].Value.ToString();

                // Получаем значения для комбо-боксов из выбранной строки
                int branchId = Convert.ToInt32(row.Cells["BranchId"].Value);
                int modelId = Convert.ToInt32(row.Cells["ModelId"].Value);
                int statusId = Convert.ToInt32(row.Cells["StatusId"].Value);

                comboBoxBranch.SelectedValue = branchId;
                comboBoxStatus.SelectedValue = statusId;
                comboBoxModel.SelectedValue = modelId;
            }
        }

        private void FormCar_Load(object sender, EventArgs e)
        {
            loadData();
        }
    }
}
