﻿using database;

namespace Forms
{
    public partial class FormCarModel : Form
    {
        private Abstractions bd;
        public FormCarModel(Abstractions _bd)
        {
            InitializeComponent();
            bd = _bd;
        }

        private void loadData()
        {
            List<CarModel> carModels = bd.GetCarModels();

            // Очищаем dataGridView перед заполнением новыми данными
            dataGridView.Rows.Clear();

            // Предварительно определяем столбцы, если это не было сделано ранее
            if (dataGridView.ColumnCount == 0)
            {
                dataGridView.Columns.Add("Id", "ID");
                dataGridView.Columns.Add("Brand", "Brand");
                dataGridView.Columns.Add("Model", "Model");
                dataGridView.Columns.Add("Year", "Year");
                dataGridView.Columns.Add("BodyType", "Body type");
                dataGridView.Columns.Add("Seats", "Seats");
            }

            // Загружаем список типов кузовов в комбо-бокс
            comboBoxBodyType.DataSource = bd.GetBodyTypes().Select(x => x.Title).ToList();

            // Заполняем dataGridView данными из списка моделей автомобилей
            foreach (CarModel carModel in carModels)
            {
                dataGridView.Rows.Add(carModel.Id, carModel.Brand, carModel.Model, carModel.Year, bd.GetBodyTypeById(carModel.BodyTypeId).Title, carModel.Seats);
            }
        }

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // Создаем новый объект CarModel с данными из текстовых полей и комбо-бокса
            CarModel newCarModel = new CarModel
            {
                Brand = textBoxBrand.Text,
                Model = textBoxModel.Text,
                Year = int.Parse(textBoxYear.Text),
                BodyTypeId = bd.GetBodyTypes().First(b => b.Title == comboBoxBodyType.SelectedItem.ToString()).Id,
                Seats = int.Parse(textBoxSeats.Text)
            };

            // Добавляем новую модель автомобиля в базу данных
            bd.AddCarModel(newCarModel);

            // Перезагружаем данные в таблицу
            loadData();
        }

        private void buttonUpdate_Click(object sender, EventArgs e)
        {
            // Получаем Id выбранной строки
            int selectedRowId = (int)dataGridView.SelectedRows[0].Cells["Id"].Value;

            // Создаем объект CarModel с обновленными данными из текстовых полей и комбо-бокса
            CarModel updatedCarModel = new CarModel
            {
                Id = selectedRowId,
                Brand = textBoxBrand.Text,
                Model = textBoxModel.Text,
                Year = int.Parse(textBoxYear.Text),
                BodyTypeId = bd.GetBodyTypes().First(b => b.Title == comboBoxBodyType.SelectedItem.ToString()).Id,
                Seats = int.Parse(textBoxSeats.Text)
            };

            // Обновляем модель автомобиля в базе данных
            bd.UpdateCarModel(updatedCarModel);

            // Перезагружаем данные в таблицу
            loadData();
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            // Получаем Id выбранной строки
            int selectedRowId = (int)dataGridView.SelectedRows[0].Cells["Id"].Value;

            // Удаляем модель автомобиля из базы данных
            bd.DeleteCarModel(selectedRowId);

            // Перезагружаем данные в таблицу
            loadData();
        }

        private void FormCarModel_Load(object sender, EventArgs e)
        {
            loadData();
        }

        private void dataGridView_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex >= 0)
            {
                DataGridViewRow row = dataGridView.Rows[e.RowIndex];

                // Заполняем текстовые поля данными из выбранной строки
                textBoxBrand.Text = row.Cells["Brand"].Value.ToString();
                textBoxModel.Text = row.Cells["Model"].Value.ToString();
                textBoxYear.Text = row.Cells["Year"].Value.ToString();
                textBoxSeats.Text = row.Cells["Seats"].Value.ToString();

                // Получаем значение типа кузова из выбранной строки
                string selectedBodyType = row.Cells["BodyType"].Value.ToString();

                // Выбираем тип кузова, который соответствует выбранному значению в строке
                comboBoxBodyType.SelectedItem = selectedBodyType;
            }
        }
    }
}
