﻿using database;
using System.Data;

namespace Forms
{
    public partial class FormRental : Form
    {
        private Abstractions bd;
        public FormRental(Abstractions _bd)
        {
            InitializeComponent();
            bd = _bd;
        }
        private void loadData()
        {
            // Получаем список аренд
            List<Rental> rentals = bd.GetRentals();

            // Очищаем dataGridView перед заполнением новыми данными
            dataGridView.Rows.Clear();

            // Предварительно определяем столбцы, если это не было сделано ранее
            if (dataGridView.ColumnCount == 0)
            {
                dataGridView.Columns.Add("Id", "ID");
                dataGridView.Columns.Add("CarId", "CarId");
                dataGridView.Columns["CarId"].Visible = false;
                dataGridView.Columns.Add("Car", "Car");
                dataGridView.Columns.Add("ClientId", "ClientId");
                dataGridView.Columns["ClientId"].Visible = false;
                dataGridView.Columns.Add("Client", "Client");
                dataGridView.Columns.Add("StartDate", "Start Date");
                dataGridView.Columns.Add("EndDate", "End Date");
                dataGridView.Columns.Add("Cost", "Cost");
            }

            // Заполняем комбо-боксы данными из БД
            comboBoxCar.DataSource = bd.GetCars()
                .Select(x => new helpCombobox()
                {
                    Text = bd.GetCarModelById(x.ModelId).Brand + " " + bd.GetCarModelById(x.ModelId).Model + " " + bd.GetStatusById(x.StatusId).Title,
                    Id = x.Id
                })
                .ToList();
            comboBoxCar.DisplayMember = "Text";
            comboBoxCar.ValueMember = "Id";

            comboBoxClient.DataSource = bd.GetClients()
                .Select(x => new helpCombobox()
                {
                    Text = x.Name + " " + x.Surname,
                    Id = x.Id
                }).ToList();
            comboBoxClient.DisplayMember = "Text"; // Используйте свойство для отображения, например, Name или Surname
            comboBoxClient.ValueMember = "Id";

            // Заполняем dataGridView данными из списка аренд
            foreach (Rental rental in rentals)
            {
                dataGridView.Rows.Add(rental.Id,
                    rental.CarId,
                    bd.GetCarModelById(bd.GetCarById(rental.CarId).ModelId).Brand + " " + bd.GetCarModelById(bd.GetCarById(rental.CarId).ModelId).Model + " " + bd.GetCarById(rental.CarId).Year.ToString(),
                    rental.ClientId,
                    bd.GetClientById(rental.ClientId).Name + " " + bd.GetClientById(rental.ClientId).Surname,
                    rental.StartDate, rental.EndDate, rental.Cost);
            }

        }

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // Создаем новый объект Rental и заполняем его данными из текстовых полей и комбо-боксов
            Rental newRental = new Rental
            {
                Cost = decimal.Parse(textBoxCost.Text),
                StartDate = DateTime.Parse(textBoxStartDate.Text),
                EndDate = DateTime.Parse(textBoxEndDate.Text),
                CarId = ((helpCombobox)comboBoxCar.SelectedItem).Id,
                ClientId = ((helpCombobox)comboBoxClient.SelectedItem).Id
            };

            // Вызываем метод добавления новой аренды в базу данных
            bd.AddRental(newRental);

            // Обновляем dataGridView
            loadData();
        }

        private void buttonUpdate_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем индекс выбранной строки
                int rowIndex = dataGridView.CurrentCell.RowIndex;

                // Получаем ID редактируемой аренды из выбранной строки dataGridView
                int rentalId = (int)dataGridView.Rows[rowIndex].Cells["Id"].Value;

                // Создаем объект Rental и заполняем его данными из текстовых полей и комбо-боксов
                Rental updatedRental = new Rental
                {
                    Id = rentalId,
                    Cost = decimal.Parse(textBoxCost.Text),
                    StartDate = DateTime.Parse(textBoxStartDate.Text),
                    EndDate = DateTime.Parse(textBoxEndDate.Text),
                    CarId = ((helpCombobox)comboBoxCar.SelectedItem).Id,
                    ClientId = ((helpCombobox)comboBoxClient.SelectedItem).Id
                };

                // Вызываем метод обновления аренды в базе данных
                bd.UpdateRental(updatedRental);

                // Обновляем dataGridView
                loadData();
            }
        }

        private void buttonDelete_Click(object sender, EventArgs e)
        {
            if (dataGridView.SelectedRows.Count > 0)
            {
                // Получаем индекс выбранной строки
                int rowIndex = dataGridView.CurrentCell.RowIndex;

                // Получаем ID удаляемой аренды из выбранной строки dataGridView
                int rentalId = (int)dataGridView.Rows[rowIndex].Cells["Id"].Value;

                // Вызываем метод удаления аренды из базы данных
                bd.DeleteRental(rentalId);

                // Обновляем dataGridView
                loadData();
            }
        }

        private void dataGridView_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex >= 0)
            {
                DataGridViewRow row = dataGridView.Rows[e.RowIndex];

                // Заполняем текстовые поля данными из выбранной строки
                textBoxCost.Text = row.Cells["Cost"].Value.ToString();
                textBoxStartDate.Text = row.Cells["StartDate"].Value.ToString();
                textBoxEndDate.Text = row.Cells["EndDate"].Value.ToString();

                // Получаем значения для комбо-боксов из выбранной строки
                int carId = Convert.ToInt32(row.Cells["CarId"].Value);
                int clientId = Convert.ToInt32(row.Cells["ClientId"].Value);

                comboBoxCar.SelectedValue = carId;

                comboBoxClient.SelectedValue = clientId;
            }
        }

        private void FormRental_Load(object sender, EventArgs e)
        {
            loadData();
        }
    }
}
